@@ -85,6 +85,30 @@ def suicide_function():
     os._exit(1)
 
 
+def process_function():
+    p = multiprocessing.Process(target=function, args=[1])
+    p.start()
+    p.join()
+
+    return 1
+
+
+def pool_function():
+    pool = multiprocessing.Pool(1)
+    result = pool.apply(function, args=[1])
+    pool.close()
+    pool.join()
+
+    return result
+
+
+def pebble_function():
+    with ProcessPool(max_workers=1) as pool:
+        f = pool.schedule(function, args=[1])
+
+    return f.result()
+
+
 @unittest.skipIf(not supported, "Start method is not supported")
 class TestProcessPool(unittest.TestCase):
     def setUp(self):
@@ -113,7 +137,7 @@ class TestProcessPool(unittest.TestCase):
     def test_process_pool_multiple_futures(self):
         """Process Pool Fork multiple futures."""
         futures = []
-        with ProcessPool(max_workers=1, context=mp_context) as pool:
+        with ProcessPool(max_workers=2, context=mp_context) as pool:
             for _ in range(5):
                 futures.append(pool.schedule(function, args=[1]))
         self.assertEqual(sum([f.result() for f in futures]), 5)
@@ -187,6 +211,7 @@ class TestProcessPool(unittest.TestCase):
         self.event.wait()
         self.assertTrue(isinstance(self.exception, CancelledError))
 
+    @unittest.skipIf(sys.platform == 'darwin', "Not supported on MAC OS")
     def test_process_pool_different_process(self):
         """Process Pool Fork multiple futures are handled by different processes."""
         futures = []
@@ -450,12 +475,12 @@ class TestProcessPool(unittest.TestCase):
 
     def test_process_pool_map_timeout_chunks(self):
         """Process Pool Fork map timeout is assigned per chunk."""
-        elements = [0.1]*10
+        elements = [0.2]*10
 
         with ProcessPool(max_workers=1, context=mp_context) as pool:
-            # it takes 0.5s to process a chunk
+            # it takes 1s to process a chunk
             future = pool.map(
-                long_function, elements, chunksize=5, timeout=0.8)
+                long_function, elements, chunksize=5, timeout=1.6)
             generator = future.result()
             self.assertEqual(list(generator), elements)
 
@@ -510,6 +535,24 @@ class TestProcessPool(unittest.TestCase):
                 except StopIteration:
                     break
 
+    def test_process_pool_child_process(self):
+        """Process Pool Fork worker starts process."""
+        with ProcessPool(max_workers=1, context=mp_context) as pool:
+            future = pool.schedule(process_function)
+        self.assertEqual(future.result(), 1)
+
+    def test_process_pool_child_pool(self):
+        """Process Pool Fork worker starts multiprocessing.Pool."""
+        with ProcessPool(max_workers=1, context=mp_context) as pool:
+            future = pool.schedule(pool_function)
+        self.assertEqual(future.result(), 1)
+
+    def test_process_pool_child_pebble(self):
+        """Process Pool Fork worker starts pebble.ProcessPool."""
+        with ProcessPool(max_workers=1, context=mp_context) as pool:
+            future = pool.schedule(pebble_function)
+        self.assertEqual(future.result(), 1)
+
 
 # DEADLOCK TESTS
 
